<?php
/**
 * @file
 * Feeds OFX parser class
 */

/**
 * Feeds OFX parser class
 */
class FeedsOFXParser extends FeedsParser {

  public function parse(FeedsSource $source, FeedsFetcherResult $fetcher_result) {

    // Begin a list of items.
    $items = array();

    // Get the raw output of the fetcher to use as the input for our parser.
    $input = $fetcher_result->getRaw();

    // Create a new OFXParser object and parse the raw output of the fetcher.
    $ofx = new OFXParser();
    $ofx->OFXParser($input);

    // Get all the transactions (debits and credits).
    $transactions = array();
    $transactions += $ofx->getCredits();
    $transactions += $ofx->getDebits();

    // Loop through all the transactions.
    if (!empty($transactions)) {
      foreach ($transactions as $transaction) {

        $items[] = array(
          'trntype' => $transaction['TRNTYPE'],
          'dtposted' => $transaction['DTPOSTED'],
          'trnamt' => $transaction['TRNAMT'],
          'fitid' => $transaction['FITID'],
          'memo' => $transaction['MEMO'],
        );
      }
    }

    // Return a parser result.
    $result = new FeedsParserResult($items);
    return $result;
  }

  public function getMappingSources() {
    return array(
      'trntype' => array(
        'name' => t('Transaction type'),
        'description' => t('Transaction type.'),
      ),
      'dtposted' => array(
        'name' => t('Date posted'),
        'description' => t('Date posted.'),
      ),
      'trnamt' => array(
        'name' => t('Transaction amount'),
        'description' => t('Transaction amount.'),
      ),
      'fitid' => array(
        'name' => t('FITID'),
        'description' => t('Unique ID.'),
      ),
      'memo' => array(
        'name' => t('Transaction memo'),
        'description' => t('Transaction memo.'),
      ),
    );
  }
}